
# Slot: correlated with


holds between any two named thing entities. For example, correlated_with holds between a disease or phenotypic feature and a measurable molecular entity that is used as an indicator of the presence or state of the disease or feature.

URI: [biolink:correlated_with](https://w3id.org/biolink/vocab/correlated_with)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [biomarker for](biomarker_for.md)
 *  [coexpressed with](coexpressed_with.md)
 *  [has biomarker](has_biomarker.md)
 *  [negatively correlated with](negatively_correlated_with.md)
 *  [positively correlated with](positively_correlated_with.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002610 |
|  | | PATO:correlates_with |
| **Narrow Mappings:** | | LOINC:associated_with |
|  | | NCIT:is_associated_disease_of |
|  | | NCIT:is_cytogenetic_abnormality_of_disease |
|  | | ORPHA:317345 |
|  | | PDQ:associated_disease |
|  | | RO:0004029 |
|  | | RTXKG1:associated_with_disease |
|  | | SNOMED:associated_with |
|  | | SNOMED:has_associated_finding |

